Proper directory_map test skip

* added the needed trailing backslash
* use is_dir() instead of opendir() as it doesn't throw error on failure
diff --git a/tests/codeigniter/helpers/directory_helper_test.php b/tests/codeigniter/helpers/directory_helper_test.php
index d860473..66e66d2 100644
--- a/tests/codeigniter/helpers/directory_helper_test.php
+++ b/tests/codeigniter/helpers/directory_helper_test.php
@@ -28,8 +28,8 @@
 
 		vfsStream::create($structure, $this->_test_dir);
 
-		// opendir() seems to fail on Windows + vfsStream when there are trailing slashes in directory names
-		if ( ! @opendir(vfsStream::url('testDir')))
+		// is_dir(), opendir(), etc. seem to fail on Windows + vfsStream when there are trailing backslashes in directory names
+		if (DIRECTORY_SEPARATOR === '\\' && ! is_dir(vfsStream::url('testDir').'\\'))
 		{
 			$this->markTestSkipped();
 			return;